utils::globalVariables(c("PredLabel", "Freq", "caret_cm", "cm",
                         "layout", "par", "rect", "text", "title",
                         "Overall", "ggplot", "aes", "reorder", "Metric",
                         "geom_point", "coord_flip", "theme_minimal",
                         "theme", "labs", "encoding_val", "."))
